DEFINE_TEST(test_acl_nfs4)
DEFINE_TEST(test_acl_pax_posix1e)
DEFINE_TEST(test_acl_pax_nfs4)
DEFINE_TEST(test_acl_platform_nfs4)
DEFINE_TEST(test_acl_platform_posix1e_restore)
DEFINE_TEST(test_acl_platform_posix1e_read)
DEFINE_TEST(test_acl_posix1e)
DEFINE_TEST(test_acl_from_text)
DEFINE_TEST(test_acl_to_text)
DEFINE_TEST(test_archive_api_feature)
DEFINE_TEST(test_archive_clear_error)
DEFINE_TEST(test_archive_cmdline)
DEFINE_TEST(test_archive_md5)
DEFINE_TEST(test_archive_rmd160)
DEFINE_TEST(test_archive_sha1)
DEFINE_TEST(test_archive_sha256)
DEFINE_TEST(test_archive_sha384)
DEFINE_TEST(test_archive_sha512)
DEFINE_TEST(test_archive_getdate)
DEFINE_TEST(test_archive_match_owner)
DEFINE_TEST(test_archive_match_path)
DEFINE_TEST(test_archive_match_time)
DEFINE_TEST(test_archive_pathmatch)
DEFINE_TEST(test_archive_read_add_passphrase)
DEFINE_TEST(test_archive_read_add_passphrase_incorrect_sequance)
DEFINE_TEST(test_archive_read_add_passphrase_single)
DEFINE_TEST(test_archive_read_add_passphrase_multiple)
DEFINE_TEST(test_archive_read_add_passphrase_set_callback1)
DEFINE_TEST(test_archive_read_add_passphrase_set_callback2)
DEFINE_TEST(test_archive_read_add_passphrase_set_callback3)
DEFINE_TEST(test_archive_read_add_passphrase_multiple_with_callback)
DEFINE_TEST(test_archive_read_add_passphrase_multiple_with_callback2)
DEFINE_TEST(test_archive_read_close_twice)
DEFINE_TEST(test_archive_read_close_twice_open_fd)
DEFINE_TEST(test_archive_read_close_twice_open_filename)
DEFINE_TEST(test_archive_read_multiple_data_objects)
DEFINE_TEST(test_archive_read_next_header_empty)
DEFINE_TEST(test_archive_read_next_header_raw)
DEFINE_TEST(test_archive_read_open2)
DEFINE_TEST(test_archive_read_set_filter_option)
DEFINE_TEST(test_archive_read_set_format_option)
DEFINE_TEST(test_archive_read_set_option)
DEFINE_TEST(test_archive_read_set_options)
DEFINE_TEST(test_archive_read_support)
DEFINE_TEST(test_archive_set_error)
DEFINE_TEST(test_archive_string)
DEFINE_TEST(test_archive_string_sort)
DEFINE_TEST(test_archive_string_conversion)
DEFINE_TEST(test_archive_write_add_filter_by_name_b64encode)
DEFINE_TEST(test_archive_write_add_filter_by_name_bzip2)
DEFINE_TEST(test_archive_write_add_filter_by_name_compress)
DEFINE_TEST(test_archive_write_add_filter_by_name_grzip)
DEFINE_TEST(test_archive_write_add_filter_by_name_gzip)
DEFINE_TEST(test_archive_write_add_filter_by_name_lrzip)
DEFINE_TEST(test_archive_write_add_filter_by_name_lz4)
DEFINE_TEST(test_archive_write_add_filter_by_name_lzip)
DEFINE_TEST(test_archive_write_add_filter_by_name_lzma)
DEFINE_TEST(test_archive_write_add_filter_by_name_lzop)
DEFINE_TEST(test_archive_write_add_filter_by_name_uuencode)
DEFINE_TEST(test_archive_write_add_filter_by_name_xz)
DEFINE_TEST(test_archive_write_add_filter_by_name_zstd)
DEFINE_TEST(test_archive_write_set_filter_option)
DEFINE_TEST(test_archive_write_set_format_by_name_7zip)
DEFINE_TEST(test_archive_write_set_format_by_name_ar)
DEFINE_TEST(test_archive_write_set_format_by_name_arbsd)
DEFINE_TEST(test_archive_write_set_format_by_name_argnu)
DEFINE_TEST(test_archive_write_set_format_by_name_arsvr4)
DEFINE_TEST(test_archive_write_set_format_by_name_bsdtar)
DEFINE_TEST(test_archive_write_set_format_by_name_cd9660)
DEFINE_TEST(test_archive_write_set_format_by_name_cpio)
DEFINE_TEST(test_archive_write_set_format_by_name_gnutar)
DEFINE_TEST(test_archive_write_set_format_by_name_iso)
DEFINE_TEST(test_archive_write_set_format_by_name_iso9660)
DEFINE_TEST(test_archive_write_set_format_by_name_mtree)
DEFINE_TEST(test_archive_write_set_format_by_name_mtree_classic)
DEFINE_TEST(test_archive_write_set_format_by_name_newc)
DEFINE_TEST(test_archive_write_set_format_by_name_odc)
DEFINE_TEST(test_archive_write_set_format_by_name_oldtar)
DEFINE_TEST(test_archive_write_set_format_by_name_pax)
DEFINE_TEST(test_archive_write_set_format_by_name_paxr)
DEFINE_TEST(test_archive_write_set_format_by_name_posix)
DEFINE_TEST(test_archive_write_set_format_by_name_rpax)
DEFINE_TEST(test_archive_write_set_format_by_name_shar)
DEFINE_TEST(test_archive_write_set_format_by_name_shardump)
DEFINE_TEST(test_archive_write_set_format_by_name_ustar)
DEFINE_TEST(test_archive_write_set_format_by_name_v7tar)
DEFINE_TEST(test_archive_write_set_format_by_name_v7)
DEFINE_TEST(test_archive_write_set_format_by_name_warc)
DEFINE_TEST(test_archive_write_set_format_by_name_xar)
DEFINE_TEST(test_archive_write_set_format_by_name_zip)
DEFINE_TEST(test_archive_write_set_format_filter_by_ext_7zip)
DEFINE_TEST(test_archive_write_set_format_filter_by_ext_zip)
DEFINE_TEST(test_archive_write_set_format_filter_by_ext_jar)
DEFINE_TEST(test_archive_write_set_format_filter_by_ext_a)
DEFINE_TEST(test_archive_write_set_format_filter_by_ext_ar)
DEFINE_TEST(test_archive_write_set_format_filter_by_ext_cpio)
DEFINE_TEST(test_archive_write_set_format_filter_by_ext_iso)
DEFINE_TEST(test_archive_write_set_format_filter_by_ext_tar)
DEFINE_TEST(test_archive_write_set_format_filter_by_ext_tar_gz)
DEFINE_TEST(test_archive_write_set_format_filter_by_ext_tar_bz2)
DEFINE_TEST(test_archive_write_set_format_filter_by_ext_tar_xz)
DEFINE_TEST(test_archive_write_set_format_filter_by_no_ext_def_zip)
DEFINE_TEST(test_archive_write_set_format_filter_by_ext_tar_bz2_def_zip)
DEFINE_TEST(test_archive_write_set_format_option)
DEFINE_TEST(test_archive_write_set_option)
DEFINE_TEST(test_archive_write_set_options)
DEFINE_TEST(test_archive_write_set_passphrase)
DEFINE_TEST(test_archive_write_set_passphrase_callback)
DEFINE_TEST(test_bad_fd)
DEFINE_TEST(test_compat_bzip2)
DEFINE_TEST(test_compat_cpio)
DEFINE_TEST(test_compat_gtar)
DEFINE_TEST(test_compat_gzip)
DEFINE_TEST(test_compat_lz4)
DEFINE_TEST(test_compat_lzip)
DEFINE_TEST(test_compat_lzma)
DEFINE_TEST(test_compat_lzop)
DEFINE_TEST(test_compat_mac)
DEFINE_TEST(test_compat_perl_archive_tar)
DEFINE_TEST(test_compat_plexus_archiver_tar)
DEFINE_TEST(test_compat_solaris_pax_sparse)
DEFINE_TEST(test_compat_solaris_tar_acl)
DEFINE_TEST(test_compat_star_acl_posix1e)
DEFINE_TEST(test_compat_star_acl_nfs4)
DEFINE_TEST(test_compat_tar_directory)
DEFINE_TEST(test_compat_tar_hardlink)
DEFINE_TEST(test_compat_uudecode)
DEFINE_TEST(test_compat_uudecode_large)
DEFINE_TEST(test_compat_xz)
DEFINE_TEST(test_compat_zip_1)
DEFINE_TEST(test_compat_zip_2)
DEFINE_TEST(test_compat_zip_3)
DEFINE_TEST(test_compat_zip_4)
DEFINE_TEST(test_compat_zip_5)
DEFINE_TEST(test_compat_zip_6)
DEFINE_TEST(test_compat_zip_7)
DEFINE_TEST(test_compat_zip_8)
DEFINE_TEST(test_compat_zstd)
DEFINE_TEST(test_empty_write)
DEFINE_TEST(test_entry)
DEFINE_TEST(test_entry_strmode)
DEFINE_TEST(test_extattr_freebsd)
DEFINE_TEST(test_filter_count)
DEFINE_TEST(test_fuzz_ar)
DEFINE_TEST(test_fuzz_cab)
DEFINE_TEST(test_fuzz_cpio)
DEFINE_TEST(test_fuzz_iso9660)
DEFINE_TEST(test_fuzz_lzh)
DEFINE_TEST(test_fuzz_mtree)
DEFINE_TEST(test_fuzz_rar)
DEFINE_TEST(test_fuzz_tar)
DEFINE_TEST(test_fuzz_zip)
DEFINE_TEST(test_gnutar_filename_encoding_UTF8_CP866)
DEFINE_TEST(test_gnutar_filename_encoding_KOI8R_UTF8)
DEFINE_TEST(test_gnutar_filename_encoding_KOI8R_CP866)
DEFINE_TEST(test_gnutar_filename_encoding_CP1251_UTF8)
DEFINE_TEST(test_gnutar_filename_encoding_ru_RU_CP1251)
DEFINE_TEST(test_gnutar_filename_encoding_Russian_Russia)
DEFINE_TEST(test_gnutar_filename_encoding_EUCJP_UTF8)
DEFINE_TEST(test_gnutar_filename_encoding_EUCJP_CP932)
DEFINE_TEST(test_gnutar_filename_encoding_CP932_UTF8)
DEFINE_TEST(test_link_resolver)
DEFINE_TEST(test_open_failure)
DEFINE_TEST(test_open_fd)
DEFINE_TEST(test_open_file)
DEFINE_TEST(test_open_filename)
DEFINE_TEST(test_pax_filename_encoding_KOI8R)
DEFINE_TEST(test_pax_filename_encoding_CP1251)
DEFINE_TEST(test_pax_filename_encoding_EUCJP)
DEFINE_TEST(test_pax_filename_encoding_CP932)
DEFINE_TEST(test_pax_filename_encoding_KOI8R_BINARY)
DEFINE_TEST(test_pax_filename_encoding_KOI8R_CP1251)
DEFINE_TEST(test_pax_filename_encoding)
DEFINE_TEST(test_pax_xattr_header)
DEFINE_TEST(test_read_data_large)
DEFINE_TEST(test_read_disk)
DEFINE_TEST(test_read_disk_directory_traversals)
DEFINE_TEST(test_read_disk_entry_from_file)
DEFINE_TEST(test_read_extract)
DEFINE_TEST(test_read_file_nonexistent)
DEFINE_TEST(test_read_filter_compress_truncated)
DEFINE_TEST(test_read_filter_compress_empty2)
DEFINE_TEST(test_read_filter_compress_invalid)
DEFINE_TEST(test_read_filter_grzip)
DEFINE_TEST(test_read_filter_lrzip)
DEFINE_TEST(test_read_filter_lzop)
DEFINE_TEST(test_read_filter_lzop_multiple_parts)
DEFINE_TEST(test_read_filter_program)
DEFINE_TEST(test_read_filter_program_signature)
DEFINE_TEST(test_read_filter_uudecode)
DEFINE_TEST(test_read_filter_uudecode_base64)
DEFINE_TEST(test_read_format_7zip)
DEFINE_TEST(test_read_format_7zip_bzip2)
DEFINE_TEST(test_read_format_7zip_from_fd)
DEFINE_TEST(test_read_format_7zip_copy)
DEFINE_TEST(test_read_format_7zip_deflate)
DEFINE_TEST(test_read_format_7zip_empty)
DEFINE_TEST(test_read_format_7zip_lzma1)
DEFINE_TEST(test_read_format_7zip_lzma2)
DEFINE_TEST(test_read_format_7zip_ppmd)
DEFINE_TEST(test_read_format_7zip_encryption_data)
DEFINE_TEST(test_read_format_7zip_encryption_header)
DEFINE_TEST(test_read_format_7zip_encryption_partially)
DEFINE_TEST(test_read_format_7zip_malformed)
DEFINE_TEST(test_read_format_7zip_packinfo_digests)
DEFINE_TEST(test_read_format_ar)
DEFINE_TEST(test_read_format_cab)
DEFINE_TEST(test_read_format_cab_filename)
DEFINE_TEST(test_read_format_cpio_afio)
DEFINE_TEST(test_read_format_cpio_bin)
DEFINE_TEST(test_read_format_cpio_bin_Z)
DEFINE_TEST(test_read_format_cpio_bin_be)
DEFINE_TEST(test_read_format_cpio_bin_bz2)
DEFINE_TEST(test_read_format_cpio_bin_gz)
DEFINE_TEST(test_read_format_cpio_bin_le)
DEFINE_TEST(test_read_format_cpio_bin_lzip)
DEFINE_TEST(test_read_format_cpio_bin_lzma)
DEFINE_TEST(test_read_format_cpio_bin_xz)
DEFINE_TEST(test_read_format_cpio_filename_eucJP_UTF8)
DEFINE_TEST(test_read_format_cpio_filename_UTF8_eucJP)
DEFINE_TEST(test_read_format_cpio_filename_UTF8_UTF8_jp)
DEFINE_TEST(test_read_format_cpio_filename_CP866_KOI8R)
DEFINE_TEST(test_read_format_cpio_filename_CP866_UTF8)
DEFINE_TEST(test_read_format_cpio_filename_KOI8R_CP866)
DEFINE_TEST(test_read_format_cpio_filename_KOI8R_UTF8)
DEFINE_TEST(test_read_format_cpio_filename_UTF8_KOI8R)
DEFINE_TEST(test_read_format_cpio_filename_UTF8_CP866)
DEFINE_TEST(test_read_format_cpio_filename_UTF8_UTF8_ru)
DEFINE_TEST(test_read_format_cpio_filename_eucJP_CP932)
DEFINE_TEST(test_read_format_cpio_filename_UTF8_CP932)
DEFINE_TEST(test_read_format_cpio_filename_CP866_CP1251)
DEFINE_TEST(test_read_format_cpio_filename_CP866_CP1251_win)
DEFINE_TEST(test_read_format_cpio_filename_KOI8R_CP1251)
DEFINE_TEST(test_read_format_cpio_filename_UTF8_CP1251)
DEFINE_TEST(test_read_format_cpio_odc)
DEFINE_TEST(test_read_format_cpio_svr4_bzip2_rpm)
DEFINE_TEST(test_read_format_cpio_svr4_gzip)
DEFINE_TEST(test_read_format_cpio_svr4_gzip_rpm)
DEFINE_TEST(test_read_format_cpio_svr4c_Z)
DEFINE_TEST(test_read_format_empty)
DEFINE_TEST(test_read_format_gtar_filename_eucJP_UTF8)
DEFINE_TEST(test_read_format_gtar_filename_CP866_KOI8R)
DEFINE_TEST(test_read_format_gtar_filename_CP866_UTF8)
DEFINE_TEST(test_read_format_gtar_filename_KOI8R_CP866)
DEFINE_TEST(test_read_format_gtar_filename_KOI8R_UTF8)
DEFINE_TEST(test_read_format_gtar_filename_eucJP_CP932)
DEFINE_TEST(test_read_format_gtar_filename_CP866_CP1251)
DEFINE_TEST(test_read_format_gtar_filename_CP866_CP1251_win)
DEFINE_TEST(test_read_format_gtar_filename_KOI8R_CP1251)
DEFINE_TEST(test_read_format_gtar_gz)
DEFINE_TEST(test_read_format_gtar_lzma)
DEFINE_TEST(test_read_format_gtar_sparse)
DEFINE_TEST(test_read_format_gtar_sparse_skip_entry)
DEFINE_TEST(test_read_format_iso_Z)
DEFINE_TEST(test_read_format_iso_multi_extent)
DEFINE_TEST(test_read_format_iso_xorriso)
DEFINE_TEST(test_read_format_isojoliet_bz2)
DEFINE_TEST(test_read_format_isojoliet_long)
DEFINE_TEST(test_read_format_isojoliet_rr)
DEFINE_TEST(test_read_format_isojoliet_versioned)
DEFINE_TEST(test_read_format_isorr_bz2)
DEFINE_TEST(test_read_format_isorr_ce)
DEFINE_TEST(test_read_format_isorr_new_bz2)
DEFINE_TEST(test_read_format_isorr_rr_moved)
DEFINE_TEST(test_read_format_isozisofs_bz2)
DEFINE_TEST(test_read_format_lha)
DEFINE_TEST(test_read_format_lha_bugfix_0)
DEFINE_TEST(test_read_format_lha_filename)
DEFINE_TEST(test_read_format_lha_filename_UTF16)
DEFINE_TEST(test_read_format_mtree)
DEFINE_TEST(test_read_format_mtree_filenames_only)
DEFINE_TEST(test_read_format_mtree_nochange)
DEFINE_TEST(test_read_format_mtree_nomagic_v1_form)
DEFINE_TEST(test_read_format_mtree_nomagic_v2_form)
DEFINE_TEST(test_read_format_mtree_nomagic_v2_netbsd_form)
DEFINE_TEST(test_read_format_mtree_nonexistent_contents_file)
DEFINE_TEST(test_read_format_mtree_noprint)
DEFINE_TEST(test_read_format_mtree_tab)
DEFINE_TEST(test_read_format_mtree_crash747)
DEFINE_TEST(test_read_format_pax_bz2)
DEFINE_TEST(test_read_format_rar_set_format)
DEFINE_TEST(test_read_format_rar_basic)
DEFINE_TEST(test_read_format_rar_subblock)
DEFINE_TEST(test_read_format_rar_noeof)
DEFINE_TEST(test_read_format_rar_unicode_UTF8)
DEFINE_TEST(test_read_format_rar_unicode_CP932)
DEFINE_TEST(test_read_format_rar_compress_normal)
DEFINE_TEST(test_read_format_rar_multi_lzss_blocks)
DEFINE_TEST(test_read_format_rar_compress_best)
DEFINE_TEST(test_read_format_rar_ppmd_lzss_conversion)
DEFINE_TEST(test_read_format_rar_binary)
DEFINE_TEST(test_read_format_rar_windows)
DEFINE_TEST(test_read_format_rar_multivolume)
DEFINE_TEST(test_read_format_rar_multivolume_skip)
DEFINE_TEST(test_read_format_rar_sfx)
DEFINE_TEST(test_read_format_rar_multivolume_stored_file)
DEFINE_TEST(test_read_format_rar_multivolume_stored_file_skip)
DEFINE_TEST(test_read_format_rar_multivolume_seek_data)
DEFINE_TEST(test_read_format_rar_multivolume_seek_multiple_files)
DEFINE_TEST(test_read_format_rar_multivolume_uncompressed_files)
DEFINE_TEST(test_read_format_rar_ppmd_use_after_free)
DEFINE_TEST(test_read_format_rar_ppmd_use_after_free2)
DEFINE_TEST(test_read_format_rar5_set_format)
DEFINE_TEST(test_read_format_rar5_stored)
DEFINE_TEST(test_read_format_rar5_compressed)
DEFINE_TEST(test_read_format_rar5_multiple_files)
DEFINE_TEST(test_read_format_rar5_multiple_files_solid)
DEFINE_TEST(test_read_format_rar5_multiarchive_skip_all)
DEFINE_TEST(test_read_format_rar5_multiarchive_skip_all_but_first)
DEFINE_TEST(test_read_format_rar5_multiarchive_skip_all_but_second)
DEFINE_TEST(test_read_format_rar5_blake2)
DEFINE_TEST(test_read_format_rar5_arm_filter)
DEFINE_TEST(test_read_format_rar5_stored_skip_all)
DEFINE_TEST(test_read_format_rar5_stored_skip_in_part)
DEFINE_TEST(test_read_format_rar5_stored_skip_all_but_first)
DEFINE_TEST(test_read_format_rar5_stored_skip_all_in_part)
DEFINE_TEST(test_read_format_rar5_multiarchive_solid_extr_all)
DEFINE_TEST(test_read_format_rar5_multiarchive_solid_skip_all)
DEFINE_TEST(test_read_format_rar5_multiarchive_solid_skip_all_but_first)
DEFINE_TEST(test_read_format_rar5_multiarchive_solid_skip_all_but_scnd)
DEFINE_TEST(test_read_format_rar5_multiarchive_solid_skip_all_but_third)
DEFINE_TEST(test_read_format_rar5_multiarchive_solid_skip_all_but_last)
DEFINE_TEST(test_read_format_rar5_solid_skip_all)
DEFINE_TEST(test_read_format_rar5_solid_skip_all_but_first)
DEFINE_TEST(test_read_format_rar5_solid_skip_all_but_second)
DEFINE_TEST(test_read_format_rar5_solid_skip_all_but_last)
DEFINE_TEST(test_read_format_rar5_extract_win32)
DEFINE_TEST(test_read_format_rar5_block_by_block)
DEFINE_TEST(test_read_format_rar5_owner)
DEFINE_TEST(test_read_format_rar5_symlink)
DEFINE_TEST(test_read_format_rar5_hardlink)
DEFINE_TEST(test_read_format_rar5_extra_field_version)
DEFINE_TEST(test_read_format_rar5_readtables_overflow)
DEFINE_TEST(test_read_format_rar5_leftshift1)
DEFINE_TEST(test_read_format_rar5_leftshift2)
DEFINE_TEST(test_read_format_rar5_truncated_huff)
DEFINE_TEST(test_read_format_rar5_invalid_dict_reference)
DEFINE_TEST(test_read_format_rar5_distance_overflow)
DEFINE_TEST(test_read_format_rar5_nonempty_dir_stream)
DEFINE_TEST(test_read_format_rar5_fileattr)
DEFINE_TEST(test_read_format_rar5_different_window_size)
DEFINE_TEST(test_read_format_rar5_window_buf_and_size_desync)
DEFINE_TEST(test_read_format_rar5_arm_filter_on_window_boundary)
DEFINE_TEST(test_read_format_rar5_different_solid_window_size)
DEFINE_TEST(test_read_format_rar5_different_winsize_on_merge)
DEFINE_TEST(test_read_format_rar5_block_size_is_too_small)
DEFINE_TEST(test_read_format_rar5_sfx)
DEFINE_TEST(test_read_format_rar5_decode_number_out_of_bounds_read)
DEFINE_TEST(test_read_format_rar5_bad_window_size_in_multiarchive_file)
DEFINE_TEST(test_read_format_rar5_read_data_block_uninitialized_offset)
DEFINE_TEST(test_read_format_rar_encryption_data)
DEFINE_TEST(test_read_format_rar_encryption_header)
DEFINE_TEST(test_read_format_rar_encryption_partially)
DEFINE_TEST(test_read_format_rar_filter)
DEFINE_TEST(test_read_format_rar_invalid1)
DEFINE_TEST(test_read_format_raw)
DEFINE_TEST(test_read_format_tar)
DEFINE_TEST(test_read_format_tar_concatenated)
DEFINE_TEST(test_read_format_tar_empty_filename)
DEFINE_TEST(test_read_format_tar_empty_pax)
DEFINE_TEST(test_read_format_tar_empty_with_gnulabel)
DEFINE_TEST(test_read_format_tar_filename)
DEFINE_TEST(test_read_format_tar_invalid_pax_size)
DEFINE_TEST(test_read_format_tbz)
DEFINE_TEST(test_read_format_tgz)
DEFINE_TEST(test_read_format_tlz)
DEFINE_TEST(test_read_format_txz)
DEFINE_TEST(test_read_format_tz)
DEFINE_TEST(test_read_format_ustar_filename)
DEFINE_TEST(test_read_format_warc)
DEFINE_TEST(test_read_format_xar)
DEFINE_TEST(test_read_format_zip)
DEFINE_TEST(test_read_format_zip_ppmd_one_file)
DEFINE_TEST(test_read_format_zip_ppmd_one_file_blockread)
DEFINE_TEST(test_read_format_zip_ppmd_multi)
DEFINE_TEST(test_read_format_zip_ppmd_multi_blockread)
DEFINE_TEST(test_read_format_zip_lzma_one_file)
DEFINE_TEST(test_read_format_zip_lzma_one_file_blockread)
DEFINE_TEST(test_read_format_zip_lzma_multi)
DEFINE_TEST(test_read_format_zip_lzma_multi_blockread)
DEFINE_TEST(test_read_format_zip_bzip2_one_file)
DEFINE_TEST(test_read_format_zip_bzip2_one_file_blockread)
DEFINE_TEST(test_read_format_zip_bzip2_multi)
DEFINE_TEST(test_read_format_zip_bzip2_multi_blockread)
DEFINE_TEST(test_read_format_zip_zstd_one_file)
DEFINE_TEST(test_read_format_zip_zstd_one_file_blockread)
DEFINE_TEST(test_read_format_zip_zstd_multi)
DEFINE_TEST(test_read_format_zip_zstd_multi_blockread)
DEFINE_TEST(test_read_format_zip_xz_multi)
DEFINE_TEST(test_read_format_zip_xz_multi_blockread)
DEFINE_TEST(test_read_format_zip_ppmd8_crash_1)
DEFINE_TEST(test_read_format_zip_bz2_hang_on_invalid)
DEFINE_TEST(test_read_format_zip_ppmd8_crash_2)
DEFINE_TEST(test_read_format_zip_lzma_alone_leak)
DEFINE_TEST(test_read_format_zip_lzma_stream_end)
DEFINE_TEST(test_read_format_zip_lzma_stream_end_blockread)
DEFINE_TEST(test_read_format_zip_7z_lzma)
DEFINE_TEST(test_read_format_zip_7z_deflate)
DEFINE_TEST(test_read_format_zip_utf8_paths)
DEFINE_TEST(test_read_format_zip_comment_stored)
DEFINE_TEST(test_read_format_zip_encryption_data)
DEFINE_TEST(test_read_format_zip_encryption_header)
DEFINE_TEST(test_read_format_zip_encryption_partially)
DEFINE_TEST(test_read_format_zip_extra_padding)
DEFINE_TEST(test_read_format_zip_filename_CP932_eucJP)
DEFINE_TEST(test_read_format_zip_filename_CP932_UTF8)
DEFINE_TEST(test_read_format_zip_filename_UTF8_eucJP)
DEFINE_TEST(test_read_format_zip_filename_UTF8_UTF8)
DEFINE_TEST(test_read_format_zip_filename_CP866_KOI8R)
DEFINE_TEST(test_read_format_zip_filename_CP866_UTF8)
DEFINE_TEST(test_read_format_zip_filename_KOI8R_CP866)
DEFINE_TEST(test_read_format_zip_filename_KOI8R_UTF8)
DEFINE_TEST(test_read_format_zip_filename_UTF8_KOI8R)
DEFINE_TEST(test_read_format_zip_filename_UTF8_CP866)
DEFINE_TEST(test_read_format_zip_filename_UTF8_UTF8_ru)
DEFINE_TEST(test_read_format_zip_filename_CP932_CP932)
DEFINE_TEST(test_read_format_zip_filename_UTF8_CP932)
DEFINE_TEST(test_read_format_zip_filename_CP866_CP1251)
DEFINE_TEST(test_read_format_zip_filename_CP866_CP1251_win)
DEFINE_TEST(test_read_format_zip_filename_KOI8R_CP1251)
DEFINE_TEST(test_read_format_zip_filename_UTF8_CP1251)
DEFINE_TEST(test_read_format_zip_filename_KOI8R_UTF8_2)
DEFINE_TEST(test_read_format_zip_high_compression)
DEFINE_TEST(test_read_format_zip_high_compression2)
DEFINE_TEST(test_read_format_zip_jar)
DEFINE_TEST(test_read_format_zip_mac_metadata)
DEFINE_TEST(test_read_format_zip_malformed)
DEFINE_TEST(test_read_format_zip_msdos)
DEFINE_TEST(test_read_format_zip_nested)
DEFINE_TEST(test_read_format_zip_nofiletype)
DEFINE_TEST(test_read_format_zip_padded1)
DEFINE_TEST(test_read_format_zip_padded2)
DEFINE_TEST(test_read_format_zip_padded3)
DEFINE_TEST(test_read_format_zip_sfx)
DEFINE_TEST(test_read_format_zip_traditional_encryption_data)
DEFINE_TEST(test_read_format_zip_winzip_aes128)
DEFINE_TEST(test_read_format_zip_winzip_aes256)
DEFINE_TEST(test_read_format_zip_winzip_aes256_stored)
DEFINE_TEST(test_read_format_zip_winzip_aes256_large)
DEFINE_TEST(test_read_format_zip_with_invalid_traditional_eocd)
DEFINE_TEST(test_read_format_zip_zip64a)
DEFINE_TEST(test_read_format_zip_zip64b)
DEFINE_TEST(test_read_large)
DEFINE_TEST(test_read_pax_truncated)
DEFINE_TEST(test_read_pax_xattr_rht_security_selinux)
DEFINE_TEST(test_read_pax_xattr_schily)
DEFINE_TEST(test_read_position)
DEFINE_TEST(test_read_set_format)
DEFINE_TEST(test_read_set_wrong_format)
DEFINE_TEST(test_read_append_filter)
DEFINE_TEST(test_read_append_wrong_filter)
DEFINE_TEST(test_read_append_filter_program)
DEFINE_TEST(test_read_append_filter_wrong_program)
DEFINE_TEST(test_read_too_many_filters)
DEFINE_TEST(test_read_truncated)
DEFINE_TEST(test_read_truncated_filter_bzip2)
DEFINE_TEST(test_read_truncated_filter_compress)
DEFINE_TEST(test_read_truncated_filter_gzip)
DEFINE_TEST(test_read_truncated_filter_lzip)
DEFINE_TEST(test_read_truncated_filter_lzma)
DEFINE_TEST(test_read_truncated_filter_lzop)
DEFINE_TEST(test_read_truncated_filter_xz)
DEFINE_TEST(test_short_writes)
DEFINE_TEST(test_sparse_basic)
DEFINE_TEST(test_fully_sparse_files)
DEFINE_TEST(test_tar_filenames)
DEFINE_TEST(test_tar_large)
DEFINE_TEST(test_ustar_filename_encoding_UTF8_CP866)
DEFINE_TEST(test_ustar_filename_encoding_KOI8R_UTF8)
DEFINE_TEST(test_ustar_filename_encoding_KOI8R_CP866)
DEFINE_TEST(test_ustar_filename_encoding_CP1251_UTF8)
DEFINE_TEST(test_ustar_filename_encoding_ru_RU_CP1251)
DEFINE_TEST(test_ustar_filename_encoding_Russian_Russia)
DEFINE_TEST(test_ustar_filename_encoding_EUCJP_UTF8)
DEFINE_TEST(test_ustar_filename_encoding_EUCJP_CP932)
DEFINE_TEST(test_ustar_filename_encoding_CP932_UTF8)
DEFINE_TEST(test_ustar_filenames)
DEFINE_TEST(test_warn_missing_hardlink_target)
DEFINE_TEST(test_write_disk)
DEFINE_TEST(test_write_disk_appledouble)
DEFINE_TEST(test_write_disk_failures)
DEFINE_TEST(test_write_disk_fixup)
DEFINE_TEST(test_write_disk_hardlink)
DEFINE_TEST(test_write_disk_hfs_compression)
DEFINE_TEST(test_write_disk_lookup)
DEFINE_TEST(test_write_disk_mac_metadata)
DEFINE_TEST(test_write_disk_no_hfs_compression)
DEFINE_TEST(test_write_disk_perms)
DEFINE_TEST(test_write_disk_secure)
DEFINE_TEST(test_write_disk_secure744)
DEFINE_TEST(test_write_disk_secure745)
DEFINE_TEST(test_write_disk_secure746a)
DEFINE_TEST(test_write_disk_secure746b)
DEFINE_TEST(test_write_disk_sparse)
DEFINE_TEST(test_write_disk_symlink)
DEFINE_TEST(test_write_disk_times)
DEFINE_TEST(test_write_filter_b64encode)
DEFINE_TEST(test_write_filter_bzip2)
DEFINE_TEST(test_write_filter_compress)
DEFINE_TEST(test_write_filter_gzip)
DEFINE_TEST(test_write_filter_gzip_timestamp)
DEFINE_TEST(test_write_filter_lrzip)
DEFINE_TEST(test_write_filter_lz4)
DEFINE_TEST(test_write_filter_lz4_disable_stream_checksum)
DEFINE_TEST(test_write_filter_lz4_enable_block_checksum)
DEFINE_TEST(test_write_filter_lz4_block_size_4)
DEFINE_TEST(test_write_filter_lz4_block_size_5)
DEFINE_TEST(test_write_filter_lz4_block_size_6)
DEFINE_TEST(test_write_filter_lz4_block_dependence)
DEFINE_TEST(test_write_filter_lzip)
DEFINE_TEST(test_write_filter_lzma)
DEFINE_TEST(test_write_filter_lzop)
DEFINE_TEST(test_write_filter_program)
DEFINE_TEST(test_write_filter_uuencode)
DEFINE_TEST(test_write_filter_xz)
DEFINE_TEST(test_write_filter_zstd)
DEFINE_TEST(test_write_format_7zip)
DEFINE_TEST(test_write_format_7zip_basic_bzip2)
DEFINE_TEST(test_write_format_7zip_basic_copy)
DEFINE_TEST(test_write_format_7zip_basic_deflate)
DEFINE_TEST(test_write_format_7zip_basic_lzma1)
DEFINE_TEST(test_write_format_7zip_basic_lzma2)
DEFINE_TEST(test_write_format_7zip_basic_ppmd)
DEFINE_TEST(test_write_format_7zip_empty_archive)
DEFINE_TEST(test_write_format_7zip_empty_files)
DEFINE_TEST(test_write_format_7zip_large_bzip2)
DEFINE_TEST(test_write_format_7zip_large_copy)
DEFINE_TEST(test_write_format_7zip_large_deflate)
DEFINE_TEST(test_write_format_7zip_large_lzma1)
DEFINE_TEST(test_write_format_7zip_large_lzma2)
DEFINE_TEST(test_write_format_7zip_large_ppmd)
DEFINE_TEST(test_write_format_ar)
DEFINE_TEST(test_write_format_cpio)
DEFINE_TEST(test_write_format_cpio_empty)
DEFINE_TEST(test_write_format_cpio_newc)
DEFINE_TEST(test_write_format_cpio_odc)
DEFINE_TEST(test_write_format_gnutar)
DEFINE_TEST(test_write_format_gnutar_filenames)
DEFINE_TEST(test_write_format_gnutar_linknames)
DEFINE_TEST(test_write_format_iso9660)
DEFINE_TEST(test_write_format_iso9660_boot)
DEFINE_TEST(test_write_format_iso9660_empty)
DEFINE_TEST(test_write_format_iso9660_filename)
DEFINE_TEST(test_write_format_iso9660_zisofs)
DEFINE_TEST(test_write_format_mtree)
DEFINE_TEST(test_write_format_mtree_no_leading_dotslash)
DEFINE_TEST(test_write_format_mtree_absolute_path)
DEFINE_TEST(test_write_format_mtree_classic)
DEFINE_TEST(test_write_format_mtree_classic_indent)
DEFINE_TEST(test_write_format_mtree_fflags)
DEFINE_TEST(test_write_format_mtree_no_separator)
DEFINE_TEST(test_write_format_mtree_quoted_filename)
DEFINE_TEST(test_write_format_pax)
DEFINE_TEST(test_write_format_raw)
DEFINE_TEST(test_write_format_raw_b64)
DEFINE_TEST(test_write_format_shar_empty)
DEFINE_TEST(test_write_format_tar)
DEFINE_TEST(test_write_format_tar_empty)
DEFINE_TEST(test_write_format_tar_sparse)
DEFINE_TEST(test_write_format_tar_ustar)
DEFINE_TEST(test_write_format_tar_v7tar)
DEFINE_TEST(test_write_format_warc)
DEFINE_TEST(test_write_format_warc_empty)
DEFINE_TEST(test_write_format_xar)
DEFINE_TEST(test_write_format_xar_empty)
DEFINE_TEST(test_write_format_zip)
DEFINE_TEST(test_write_format_zip64)
DEFINE_TEST(test_write_format_zip_traditional_pkware_encryption)
DEFINE_TEST(test_write_format_zip_winzip_aes128_encryption)
DEFINE_TEST(test_write_format_zip_winzip_aes256_encryption)
DEFINE_TEST(test_write_format_zip_compression_store)
DEFINE_TEST(test_write_format_zip_empty)
DEFINE_TEST(test_write_format_zip_empty_zip64)
DEFINE_TEST(test_write_format_zip_size_unset)
DEFINE_TEST(test_write_format_zip_file)
DEFINE_TEST(test_write_format_zip_file_zip64)
DEFINE_TEST(test_write_format_zip_large)
DEFINE_TEST(test_write_format_zip_zip64_oversize)
DEFINE_TEST(test_write_open_memory)
DEFINE_TEST(test_write_read_format_zip)
DEFINE_TEST(test_write_read_format_zip_improved_streaming)
DEFINE_TEST(test_write_read_format_zip64)
DEFINE_TEST(test_write_read_format_zip64_improved_streaming)
DEFINE_TEST(test_xattr_platform)
DEFINE_TEST(test_zip_filename_encoding_UTF8)
DEFINE_TEST(test_zip_filename_encoding_KOI8R)
DEFINE_TEST(test_zip_filename_encoding_ru_RU_CP1251)
DEFINE_TEST(test_zip_filename_encoding_Russian_Russia)
DEFINE_TEST(test_zip_filename_encoding_EUCJP)
DEFINE_TEST(test_zip_filename_encoding_CP932)
